VdpReferenceFrameH264

Struct VdpReferenceFrameH264 

#[repr(C)]
pub struct VdpReferenceFrameH264 { pub surface: VdpVideoSurface, pub is_long_term: VdpBool, pub top_is_reference: VdpBool, pub bottom_is_reference: VdpBool, pub field_order_cnt: [i32; 2], pub frame_idx: u16, }
\brief Information about an H.264 reference frame

Note: References to “copy of bitstream field” in the field descriptions may refer to data literally parsed from the bitstream, or derived from the bitstream using a mechanism described in the specification.

Fields

surface: VdpVideoSurface

The surface that contains the reference image. Set to VDP_INVALID_HANDLE for unused entries.

is_long_term: VdpBool

Is this a long term reference (else short term).

top_is_reference: VdpBool

Is the top field used as a reference. Set to VDP_FALSE for unused entries.

bottom_is_reference: VdpBool

Is the bottom field used as a reference. Set to VDP_FALSE for unused entries.

field_order_cnt: [i32; 2]

[0]: top, [1]: bottom

frame_idx: u16

Copy of the H.264 bitstream field: frame_num from slice_header for short-term references, LongTermPicNum from decoding algorithm for long-term references.