VdpBitmapSurfaceCreate

Type Alias VdpBitmapSurfaceCreate 

pub type VdpBitmapSurfaceCreate = Option<unsafe extern "C" fn(device: VdpDevice, rgba_format: VdpRGBAFormat, width: u32, height: u32, frequently_accessed: VdpBool, surface: *mut VdpBitmapSurface) -> VdpStatus>;
\brief Create a VdpBitmapSurface. \param[in] device The device that will contain the surface. \param[in] rgba_format The format of the new surface. \param[in] width The width of the new surface. \param[in] height The height of the new surface. \param[in] frequently_accessed Is this bitmap used frequently, or infrequently, by compositing options? Implementations may use this as a hint to determine how to allocate the underlying storage for the surface. \param[out] surface The new surface’s handle. \return VdpStatus The completion status of the operation.

The memory backing the surface may not be initialized during creation. Applications are expected initialize any region that they use, via \ref VdpBitmapSurfacePutBitsNative.

Aliased Type

pub enum VdpBitmapSurfaceCreate {
    None,
    Some(unsafe extern "C" fn(u32, u32, u32, u32, i32, *mut u32) -> u32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(u32, u32, u32, u32, i32, *mut u32) -> u32)

Some value of type T.