VdpDecoderCreate

Type Alias VdpDecoderCreate 

pub type VdpDecoderCreate = Option<unsafe extern "C" fn(device: VdpDevice, profile: VdpDecoderProfile, width: u32, height: u32, max_references: u32, decoder: *mut VdpDecoder) -> VdpStatus>;
\brief Create a VdpDecoder. \param[in] device The device that will contain the surface. \param[in] profile The video format the decoder will decode. \param[in] width The width of the new surface. \param[in] height The height of the new surface. \param[in] max_references The maximum number of references that may be used by a single frame in the stream to be decoded. This parameter exists mainly for formats such as H.264, where different streams may use a different number of references. Requesting too many references may waste memory, but decoding should still operate correctly. Requesting too few references will cause decoding to fail. \param[out] decoder The new decoder’s handle. \return VdpStatus The completion status of the operation.

Aliased Type

pub enum VdpDecoderCreate {
    None,
    Some(unsafe extern "C" fn(u32, u32, u32, u32, u32, *mut u32) -> u32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(u32, u32, u32, u32, u32, *mut u32) -> u32)

Some value of type T.