pub type VdpDecoderQueryCapabilities = Option<unsafe extern "C" fn(device: VdpDevice, profile: VdpDecoderProfile, is_supported: *mut VdpBool, max_level: *mut u32, max_macroblocks: *mut u32, max_width: *mut u32, max_height: *mut u32) -> VdpStatus>;Expand description
\brief Query the implementation’s VdpDecoder capabilities. \param[in] device The device to query. \param[in] profile The decoder profile for which information is requested. \param[out] is_supported Is this profile supported? \param[out] max_level The maximum specification level supported for this profile. \param[out] max_macroblocks The maximum supported surface size in macroblocks. Note that this could be greater than that dictated by the maximum level. \param[out] max_width The maximum supported surface width for this profile. Note that this could be greater than that dictated by the maximum level. \param[out] max_height The maximum supported surface height for this profile. Note that this could be greater than that dictated by the maximum level. \return VdpStatus The completion status of the operation.
Aliased Type
pub enum VdpDecoderQueryCapabilities {
None,
Some(unsafe extern "C" fn(u32, u32, *mut i32, *mut u32, *mut u32, *mut u32, *mut u32) -> u32),
}