pub type VdpGetErrorString = Option<unsafe extern "C" fn(status: VdpStatus) -> *const c_char>;Expand description
\brief Retrieve a string describing an error code. \param[in] status The error code. \return A pointer to the string. Note that this is a statically allocated read-only string. As such, the application must not free the returned pointer. The pointer is valid as long as the VDPAU implementation is present within the application’s address space.
Aliased Type
pub enum VdpGetErrorString {
None,
Some(unsafe extern "C" fn(u32) -> *const i8),
}