VdpPresentationQueueQuerySurfaceStatus

Type Alias VdpPresentationQueueQuerySurfaceStatus 

pub type VdpPresentationQueueQuerySurfaceStatus = Option<unsafe extern "C" fn(presentation_queue: VdpPresentationQueue, surface: VdpOutputSurface, status: *mut VdpPresentationQueueStatus, first_presentation_time: *mut VdpTime) -> VdpStatus>;
\brief Poll the current queue status of a surface. \param[in] presentation_queue The queue to query. \param[in] surface The surface to query. \param[out] status The current status of the surface within the queue. \param[out] first_presentation_time The timestamp of the VSYNC at which this surface was first displayed. Note that 0 means the surface was never displayed. \return VdpStatus The completion status of the operation.

Aliased Type

pub enum VdpPresentationQueueQuerySurfaceStatus {
    None,
    Some(unsafe extern "C" fn(u32, u32, *mut u32, *mut u64) -> u32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(u32, u32, *mut u32, *mut u64) -> u32)

Some value of type T.