pub type VdpVideoSurfaceQueryCapabilities = Option<unsafe extern "C" fn(device: VdpDevice, surface_chroma_type: VdpChromaType, is_supported: *mut VdpBool, max_width: *mut u32, max_height: *mut u32) -> VdpStatus>;Expand description
\brief Query the implementation’s VdpVideoSurface capabilities. \param[in] device The device to query. \param[in] surface_chroma_type The type of chroma type for which information is requested. \param[out] is_supported Is this chroma type supported? \param[out] max_width The maximum supported surface width for this chroma type. \param[out] max_height The maximum supported surface height for this chroma type. \return VdpStatus The completion status of the operation.
Aliased Type
pub enum VdpVideoSurfaceQueryCapabilities {
None,
Some(unsafe extern "C" fn(u32, u32, *mut i32, *mut u32, *mut u32) -> u32),
}