#[repr(C)]pub struct VdpColor {
pub red: f32,
pub green: f32,
pub blue: f32,
pub alpha: f32,
}Expand description
A constant RGBA color.
Note that the components are stored as float values in the range 0.0…1.0 rather than format-specific integer values. This allows VdpColor values to be independent from the exact surface format(s) in use.
Fields
red: f32green: f32blue: f32alpha: f32Trait Implementations