pub type VdpDecoderGetParameters = Option<unsafe extern "C" fn(decoder: VdpDecoder, profile: *mut VdpDecoderProfile, width: *mut u32, height: *mut u32) -> VdpStatus>;Expand description
\brief Retrieve the parameters used to create a VdpDecoder. \param[in] surface The surface’s handle. \param[out] profile The video format used to create the decoder. \param[out] width The width of surfaces decode by the decoder. \param[out] height The height of surfaces decode by the decoder \return VdpStatus The completion status of the operation.
Aliased Type
pub enum VdpDecoderGetParameters {
None,
Some(unsafe extern "C" fn(u32, *mut u32, *mut u32, *mut u32) -> u32),
}