pub type VdpDecoderRender = Option<unsafe extern "C" fn(decoder: VdpDecoder, target: VdpVideoSurface, picture_info: *const VdpPictureInfo, bitstream_buffer_count: u32, bitstream_buffers: *const VdpBitstreamBuffer) -> VdpStatus>;Expand description
\brief Decode a compressed field/frame and render the result into a \ref VdpVideoSurface “VdpVideoSurface”. \param[in] decoder The decoder object that will perform the decode operation. \param[in] target The video surface to render to. \param[in] picture_info A (pointer to a) structure containing information about the picture to be decoded. Note that the appropriate type of VdpPictureInfo* structure must be provided to match to profile that the decoder was created for. \param[in] bitstream_buffer_count The number of bitstream buffers containing compressed data for this picture. \param[in] bitstream_buffers An array of bitstream buffers. \return VdpStatus The completion status of the operation.
See \ref video_mixer_usage for additional information.
Aliased Type
pub enum VdpDecoderRender {
None,
Some(unsafe extern "C" fn(u32, u32, *const *mut c_void, u32, *const VdpBitstreamBuffer) -> u32),
}